BidiSpan class

Represents a contiguous range of text that has a single direction.

Bidi spans are the result of applying the Unicode Bidirectional Algorithm to a line of text. Each span has a from/to range (relative to line start) and a bidi level that determines direction.

Constructors

BidiSpan(int from, int to, int level)
const

Properties

dir Direction
Get the direction of this span.
no setter
from int
The start of the span (relative to line start).
final
hashCode int
The hash code for this object.
no setteroverride
level int
The bidi level of the span.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int
The end of the span.
final

Methods

forward(bool isForward, Direction dir) bool
Check if movement in the given direction is forward in this span.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
side(bool end, Direction dir) int
Get the position on a given side of the span.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

find(List<BidiSpan> order, int index, int level, int assoc) int
Find a span containing the given index.