Command typedef

Command = bool Function(dynamic view)

A command is a function that takes an EditorView and returns whether it was able to perform some action.

Commands are typically bound to keyboard shortcuts via KeyBinding.

When a command function returns false, it indicates that the command did not apply in the current situation and other handlers should be tried. When it returns true, it means the command handled the event.

Implementation

typedef Command = bool Function(dynamic view);