FacetConfig<Input, Output> class

Configuration options for defining a facet.

Constructors

FacetConfig({Output combine(List<Input> values)?, bool compare(Output a, Output b)?, bool compareInput(Input a, Input b)?, bool isStatic = false, Object? enables})
const

Properties

combine → Output Function(List<Input> values)?
How to combine the input values into a single output value.
final
compare bool Function(Output a, Output b)?
How to compare output values to determine whether the value of the facet changed.
final
compareInput bool Function(Input a, Input b)?
How to compare input values to avoid recomputing the output value when no inputs changed.
final
enables Object?
If given, these extension(s) (or the result of calling the given function with the facet) will be added to any state where this facet is provided.
final
hashCode int
The hash code for this object.
no setterinherited
isStatic bool
Forbids dynamic inputs to this facet.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited