compare property

bool Function(Output a, Output b)? compare
final

How to compare output values to determine whether the value of the facet changed.

Defaults to comparing by == or, if no combine function was given, comparing each element of the list with ==.

Implementation

final bool Function(Output a, Output b)? compare;