compareInput property
How to compare input values to avoid recomputing the output value when no inputs changed.
Defaults to comparing with ==.
Implementation
final bool Function(Input a, Input b)? compareInput;
How to compare input values to avoid recomputing the output value when no inputs changed.
Defaults to comparing with ==.
final bool Function(Input a, Input b)? compareInput;