FoldConfig class
Configuration for code folding.
Constructors
- FoldConfig({String placeholderText = '…'})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeholderText → String
-
Text to use as placeholder for folded text.
Defaults to
"…".final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited