FormatEdit class

A single text edit returned by a formatter.

Constructors

FormatEdit({required int from, required int to, required String newText})
const
FormatEdit.delete(int from, int to)
Create a delete edit (text removed, nothing inserted).
factory
FormatEdit.insert(int pos, String text)
Create an insert edit (no text replaced).
factory
FormatEdit.replace(int from, int to, String newText)
Create a replace edit.
factory

Properties

from int
The start position of the edit.
final
hashCode int
The hash code for this object.
no setterinherited
newText String
The new text to insert at this range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to int
The end position of the edit (exclusive).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited