GotoDefinitionConfig class

Internal configuration for a definition source.

Constructors

GotoDefinitionConfig({required DefinitionSource source, required GotoDefinitionOptions options})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
options GotoDefinitionOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source DefinitionSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited