HoverTooltip class

Describes a hover tooltip to be shown.

Named HoverTooltip to avoid collision with Flutter's Tooltip widget.

Constructors

HoverTooltip({required int pos, int? end, required TooltipView create(BuildContext context), bool above = false, bool strictSide = false, bool arrow = false, bool clip = true})
const

Properties

above bool
Whether the tooltip should be shown above the target position.
final
arrow bool
When set to true, show a triangle connecting the tooltip to the position.
final
clip bool
By default, tooltips are hidden when their position is outside the visible editor content. Set this to false to turn that off.
final
create TooltipView Function(BuildContext context)
A function that creates the tooltip's widget.
final
end int?
The end of the range annotated by this tooltip, if different from pos.
final
hashCode int
The hash code for this object.
no setterinherited
pos int
The document position at which to show the tooltip.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strictSide bool
Whether the above option should be honored when there isn't enough space on that side. Defaults to false.
final

Methods

copyWith({int? pos, int? end, TooltipView create(BuildContext context)?, bool? above, bool? strictSide, bool? arrow, bool? clip}) HoverTooltip
Create a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited