IndentContextOptions class

Options for creating an IndentContext.

Constructors

IndentContextOptions({int overrideIndentation(int pos)?, int? simulateBreak, bool simulateDoubleBreak = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
overrideIndentation int Function(int pos)?
Override line indentations provided to the indentation helper function.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simulateBreak int?
Make it look, to the indent logic, like a line break was added at the given position.
final
simulateDoubleBreak bool
When simulateBreak is given, this can be used to make the simulated break behave like a double line break.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited