RegExpCursorOptions class

Options for creating a RegExpCursor.

Constructors

RegExpCursorOptions({bool ignoreCase = false, bool test(int from, int to, RegExpMatch match)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ignoreCase bool
Whether to ignore case when matching.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
test bool Function(int from, int to, RegExpMatch match)?
Optional test function to filter matches.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited