RenameOptions class

Configuration options for rename symbol.

Constructors

RenameOptions({PrepareRenameSource? prepareSource, WorkspaceRenameHandler? workspaceHandler, bool showPreview = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
prepareSource PrepareRenameSource?
Optional prepare source to check if rename is possible.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPreview bool
Whether to show a preview before applying the rename.
final
workspaceHandler WorkspaceRenameHandler?
Handler for workspace (cross-file) renames.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited