ReplaceDecorationSpec class

Configuration for creating a replace decoration.

Constructors

ReplaceDecorationSpec({WidgetType? widget, bool? inclusive, bool? inclusiveStart, bool? inclusiveEnd, bool block = false, Map<String, dynamic>? spec, bool isBlockGap = false})
const

Properties

block bool
Whether this is a block-level replacement.
final
hashCode int
The hash code for this object.
no setterinherited
inclusive bool?
Whether this range covers the positions on its sides.
final
inclusiveEnd bool?
Whether the end is inclusive.
final
inclusiveStart bool?
Whether the start is inclusive.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec Map<String, dynamic>?
Additional custom data.
final
widget WidgetType?
Optional widget to display in place of the replaced content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited