SelectionConfig class

Configuration for selection and cursor rendering.

Annotations

Constructors

SelectionConfig({int cursorBlinkRate = 1200, bool drawRangeCursor = true, double cursorWidth = 2.0, Radius? cursorRadius, Color? cursorColor, Color? secondaryCursorColor, Color? selectionColor})
const

Properties

cursorBlinkRate int
The duration of a full cursor blink cycle in milliseconds.
final
cursorColor Color?
The color of the primary cursor.
final
cursorRadius Radius?
The cursor radius for rounded corners.
final
cursorWidth double
The cursor width in logical pixels.
final
drawRangeCursor bool
Whether to show a cursor for non-empty (range) selections.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryCursorColor Color?
The color of secondary cursors (in multi-cursor mode).
final
selectionColor Color?
The selection highlight color.
final

Methods

copyWith({int? cursorBlinkRate, bool? drawRangeCursor, double? cursorWidth, Radius? cursorRadius, Color? cursorColor, Color? secondaryCursorColor, Color? selectionColor}) SelectionConfig
Create a copy with modified values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override