SemanticTokensClient class abstract

Interface for LSP semantic token requests.

Implement this to connect to your language server.

Constructors

SemanticTokensClient()

Properties

documentUri String
The document URI for the current document.
no setter
hashCode int
The hash code for this object.
no setterinherited
legend SemanticTokensLegend
The legend from the server's capabilities.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestSemanticTokensDelta(String uri, String previousResultId) Future<SemanticTokensDeltaResult?>
Request delta semantic tokens (optional optimization).
requestSemanticTokensFull(String uri) Future<SemanticTokensResult?>
Request full semantic tokens for a document.
requestSemanticTokensRange(String uri, int startLine, int startChar, int endLine, int endChar) Future<SemanticTokensResult?>
Request semantic tokens for a range (optional optimization).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited