VP class abstract final

Constants for viewport management.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

margin → const int
Margin around the viewport to render (in pixels).
maxCoverMargin → const int
Maximum cover margin.
maxDOMHeight → const int
Maximum DOM height before scaling kicks in.
maxHorizGap → const int
Maximum horizontal gap before collapsing.
minCoverMargin → const int
Minimum cover margin required.