cursorDocStart function
Move the selection to the start of the document.
Implementation
bool cursorDocStart(StateCommandTarget target) {
target.dispatch(_setSel(target.state, EditorSelection.single(0)));
return true;
}
Move the selection to the start of the document.
bool cursorDocStart(StateCommandTarget target) {
target.dispatch(_setSel(target.state, EditorSelection.single(0)));
return true;
}