darkTheme top-level property

Facet<bool, bool> darkTheme
final

Facet indicating whether the editor should use dark theme styling.

When any value is true, dark theme is active.

Implementation

final Facet<bool, bool> darkTheme = Facet.define(
  FacetConfig(combine: (values) => values.any((v) => v)),
);