getTooltip function
Get the active tooltip view for a given tooltip, if available.
Implementation
TooltipView? getTooltip(EditorState state, HoverTooltip tooltip) {
return null;
}
Get the active tooltip view for a given tooltip, if available.
TooltipView? getTooltip(EditorState state, HoverTooltip tooltip) {
return null;
}