gutters function

Extension gutters({
  1. bool fixed = true,
})

The gutter-drawing extension is automatically enabled when you add a gutter, but you can use this function to explicitly configure it.

Unless fixed is explicitly set to false, the gutters are fixed, meaning they don't scroll along with the content horizontally.

Implementation

Extension gutters({bool fixed = true}) {
  final extensions = <Extension>[
    _guttersEnabled.of(true),
  ];
  if (!fixed) {
    extensions.add(_unfixGutters.of(true));
  }
  return ExtensionList(extensions);
}