Diagnostic class
Describes a problem or hint for a piece of code.
Constructors
-
Diagnostic({required int from, required int to, required Severity severity, required String message, String? markClass, String? source, List<
DiagnosticAction> ? actions}) -
const
Properties
-
actions
→ List<
DiagnosticAction> ? -
An optional array of actions that can be taken on this diagnostic.
final
- from → int
-
The start position of the relevant text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- markClass → String?
-
When given, add an extra CSS class to parts of the code that
this diagnostic applies to.
final
- message → String
-
The message associated with this diagnostic.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
The severity of the problem.
final
- source → String?
-
An optional source string indicating where the diagnostic is
coming from. You can put the name of your linter here.
final
- to → int
-
The end position. May be equal to from, though actually
covering text is preferable.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited