EditorViewConfig class
Configuration for creating an EditorView.
Constructors
-
EditorViewConfig({EditorState? state, String? doc, EditorSelection? selection, Extension? extensions, void dispatchTransactions(List<
Transaction> transactions, EditorView view)?, StateEffect<ScrollTarget> ? scrollTo, bool readOnly = false, bool autofocus = false}) -
const
Properties
- autofocus → bool
-
Whether the editor should auto-focus.
final
-
dispatchTransactions
→ void Function(List<
Transaction> transactions, EditorView view)? -
Custom dispatch handler.
final
- doc → String?
-
Initial document content (used if state is not provided).
final
- extensions → Extension?
-
Extensions to use (used if state is not provided).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- readOnly → bool
-
Whether the editor should be read-only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scrollTo
→ StateEffect<
ScrollTarget> ? -
Initial scroll target.
final
- selection → EditorSelection?
-
Initial selection (used if state is not provided).
final
- state → EditorState?
-
The initial editor state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited