HighlightingTextEditingController class
A TextEditingController that applies syntax highlighting.
This controller overrides buildTextSpan to apply styling from decoration ranges. It reads decorations from the decorations facet and converts them to Flutter TextStyles.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
TextEditingValue> - TextEditingController
- HighlightingTextEditingController
Constructors
-
HighlightingTextEditingController({String? text, RangeSet<
Decoration> getDecorations()?, HighlightTheme theme = const HighlightTheme(), ({int from, int to})? linkRange, Color linkColor = const Color(0xFF0066CC)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- linkColor ↔ Color
-
Color for the link underline.
getter/setter pair
- linkRange ↔ ({int from, int to})?
-
Optional link range to show as underlined (for Ctrl+hover go-to-definition).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection ↔ TextSelection
-
The currently selected range within text.
getter/setter pairinherited
- text ↔ String
-
The current string the user is editing.
getter/setter pairinherited
- theme → HighlightTheme
-
Theme for mapping class names to styles.
final
- value ↔ TextEditingValue
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
buildTextSpan(
{required BuildContext context, TextStyle? style, required bool withComposing}) → TextSpan -
Builds TextSpan from current editing value.
override
-
clear(
) → void -
Set the value to empty.
inherited
-
clearComposing(
) → void -
Set the composing region to an empty range.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited