LineDecoration class
A decoration that adds attributes to an entire line.
Line decorations affect the line element that wraps the text content. They can only be placed at the start of a line (zero-length range).
- Inheritance
-
- Object
- RangeValue
- Decoration
- LineDecoration
Properties
-
attributes
→ Map<
String, String> ? -
Additional attributes.
final
- className → String?
-
The CSS class name.
final
- endSide → int
-
The bias value at the end of the range. Defaults to 0.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPoint → bool
-
Whether this decoration is a point (zero-length) decoration.
no setter
- mapMode → MapMode
-
The mode with which the location of the range should be mapped
when its
fromandtoare the same, to decide whether a change deletes the range. Defaults toMapMode.trackDel.no setteroverride - point → bool
-
Determines whether this value marks a point range. Regular
ranges affect the part of the document they cover, and are
meaningless when empty. Point ranges have a meaning on their
own. When non-empty, a point range is treated as atomic and
shadows any ranges contained in it.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spec
→ Map<
String, dynamic> ? -
The spec object used to create this decoration.
finalinherited
- startSide → int
-
The bias value at the start of the range. Determines how the
range is positioned relative to other ranges starting at this
position. Defaults to 0.
no setterinherited
Methods
-
eq(
RangeValue other) → bool -
Check if two decorations are equivalent.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
range(
int from, [int? to]) → Range< Decoration> -
Create a Range with this value.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited