PortalSpacing class
Calculates spacing between a widget and its portal based on their anchors.
Spacing is applied when anchors are on opposite sides. For example, if childAnchor is bottomLeft and portalAnchor is topLeft, spacing pushes the portal down.
Constructors
- PortalSpacing(double spacing, {bool diagonal = false})
-
const
Properties
Methods
-
call(
Alignment child, Alignment portal) → Offset - Calculate the spacing offset based on anchor alignment relationship.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- zero → const PortalSpacing
- No spacing.