TooltipConfig class
Configuration for the tooltip system.
Constructors
- TooltipConfig({TooltipRect tooltipSpace(BuildContext context)?, bool showArrow = true, int hoverDelay = 300})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverDelay → int
-
Duration before hover tooltips appear (in milliseconds).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArrow → bool
-
Whether to show arrows connecting tooltips to their anchor positions.
final
- tooltipSpace → TooltipRect Function(BuildContext context)?
-
The space available for tooltips.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited